@@ -5,11 +5,17 @@ from derpconf.config import Config  # NOQA
 
 MINUTE = 60
 HOUR = MINUTE * 60
+DAY = 24 * HOUR
 
 Config.define('WORKER_SLEEP_TIME', 10, 'Main loop sleep time', 'Worker')
 Config.define('ZOMBIE_WORKER_TIME', 200,
               'Time to remove a Worker from API List (must be greater than WORKER_SLEEP_TIME + Validation time)', 'API')
 
+Config.define('WORKERS_LOOK_AHEAD_PAGES', 1000, 'Number of pages that will be retrieved when looking for the next job', 'Worker')
+
+Config.define('UPDATE_PAGES_SCORE_EXPIRATION', 30, 'The expiration for lock to update pages score', 'Worker')
+Config.define('UPDATE_PAGES_SCORE_SLEEP_TIME', HOUR, 'The expiration for lock to update pages score', 'Worker')
+
 Config.define('CONNECT_TIMEOUT_IN_SECONDS', 20, 'Number of seconds a connection can take.', 'Worker')
 Config.define('REQUEST_TIMEOUT_IN_SECONDS', 60, 'Number of seconds a request can take.', 'Worker')
 
@@ -26,6 +32,8 @@ Config.define('VALIDATORS', [], 'List of classes to validate a website', 'Review
 Config.define('REVIEW_EXPIRATION_IN_SECONDS', 6 * 60 * 60, 'Number of seconds that a review expires in.', 'Review')
 Config.define('NUMBER_OF_REVIEWS_TO_KEEP', 4, 'Maximum number of reviews to keep', 'Review')
 
+Config.define('DAYS_TO_KEEP_REQUESTS', 12, 'Number of days to keep requests', 'Requests')
+
 Config.define('MAX_ENQUEUE_BUFFER_LENGTH', 1000,
               'Number of urls to enqueue before submitting to the /pages route', 'Validators')
 
@@ -49,6 +57,9 @@ Config.define('MAX_JS_REQUESTS_PER_PAGE', 17,
 Config.define('MAX_JS_KB_PER_PAGE_AFTER_GZIP', 272,
               'Maximum size of scripts per page after gzip', 'JS Request Validator')
 
+Config.define('MAX_HEADING_HIEARARCHY_SIZE', 150,
+              'Heading Hierarchy tags longer than 150 characters may be truncated in the results',
+              'Heading Hierarchy Validator')
 Config.define('MAX_TITLE_SIZE', 70,
               'Title tags longer than 70 characters may be truncated in the results',
               'Title Validator')
@@ -102,8 +113,10 @@ Config.define('REQUESTS_COUNT_EXPIRATION_IN_SECONDS', HOUR, 'Expiration for the
 materials_expiration_in_seconds = {
     'domains_details': 0.5 * MINUTE + 1,
     'next_jobs_count': 13,
-    'violation_count_by_category_for_domains': 3 * MINUTE + 7,
-    'blacklist_domain_count': 10 * MINUTE + 1
+    'violation_count_by_category_for_domains': 3 * MINUTE + 11,
+    'blacklist_domain_count': 10 * MINUTE + 1,
+    'most_common_violations': HOUR + 7,
+    'old_requests': (lambda config: config.get('DAYS_TO_KEEP_REQUESTS') * DAY - 1),
 }
 Config.define('MATERIALS_EXPIRATION_IN_SECONDS', materials_expiration_in_seconds, 'Expire times for materials', 'material')
 
@@ -112,6 +125,8 @@ materials_grace_period_in_seconds = {
     'next_jobs_count': 2 * materials_expiration_in_seconds['next_jobs_count'],
     'violation_count_by_category_for_domains': 2 * materials_expiration_in_seconds['violation_count_by_category_for_domains'],
     'blacklist_domain_count': 2 * materials_expiration_in_seconds['blacklist_domain_count'],
+    'most_common_violations': 2 * materials_expiration_in_seconds['most_common_violations'],
+    'old_requests': (lambda config: 2 * materials_expiration_in_seconds['old_requests'](config)),
 }
 Config.define('MATERIALS_GRACE_PERIOD_IN_SECONDS', materials_grace_period_in_seconds, 'Grace period times for materials', 'material')
 
@@ -134,6 +149,7 @@ Config.define('MOST_COMMON_VIOLATIONS_SAMPLE_LIMIT', 50000, 'Limit for the size
 
 throttling_message_type = {
     'new-request': 5,
-    'worker-status': 2,
+    'new-page': 2,
+    'new-review': 2,
 }
 Config.define('EVENT_BUS_THROTTLING_MESSAGE_TYPE', throttling_message_type, 'Trottling by message type', 'Event Bus')
