@@ -235,6 +235,9 @@ class DomainsChangeStatusHandler(BaseHandler):
 
         domain.is_active = not domain.is_active
 
+        if not domain.is_active:
+            yield self.cache.delete_limit_usage_by_domain(domain.url)
+
     @coroutine
     def options(self, domain_name):
         super(DomainsChangeStatusHandler, self).options()
